@@ -115,8 +115,10 @@ class Base(object):
                 sql += '%s ,' % i
             sql = sql[:-1]
 
-        if order is not None:
+        if order is not None and order[0] != 'id':
             sql += 'order by %s %s , id %s ' % (order[0], order[1], order[1])
+        if order[0] == 'id':
+            sql += 'order by %s %s '%(order[0], order[1])
 
         if limit is not None:
             sql += 'limit '
